==> jc-1.4.0.tar.gz: java/security/cert/PKIXCertPathBuilderResult.h <==
// public class java.security.cert.PKIXCertPathBuilderResult

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5f136bcfecde6164 java_security_cert_PKIXCertPathBuilderResult
// @dep_class e755c7543ee532d3 java_security_cert_PKIXCertPathValidatorResult

// header file dependencies
// @dep_header java_security_cert_PKIXCertPathValidatorResult

#include "java/security/cert/PKIXCertPathValidatorResult.h"

#ifndef _JC_java_security_cert_PKIXCertPathBuilderResult_H_
#define _JC_java_security_cert_PKIXCertPathBuilderResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_PolicyNode$object;
struct _jc_java_security_cert_TrustAnchor$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs	_jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs	_jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$refs	_jc_java_security_cert_PKIXCertPathBuilderResult$refs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs	_jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$object	_jc_java_security_cert_PKIXCertPathBuilderResult$object;

typedef const struct _jc_java_security_cert_PKIXCertPathBuilderResult$vmethods	_jc_java_security_cert_PKIXCertPathBuilderResult$vmethods;
typedef const struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtable	_jc_java_security_cert_PKIXCertPathBuilderResult$vtable;
typedef const struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtype	_jc_java_security_cert_PKIXCertPathBuilderResult$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXCertPathBuilderResult$method$_init$c83cbb9627382e21(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_security_cert_CertPath$object *_jc_java_security_cert_PKIXCertPathBuilderResult$method$getCertPath$5edc3811abd6d88d(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PKIXCertPathBuilderResult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXCertPathBuilderResult$method_info$getCertPath$5edc3811abd6d88d;
extern _jc_method _jc_java_security_cert_PKIXCertPathBuilderResult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PKIXCertPathBuilderResult$vmethods {
	struct _jc_java_security_cert_CertPath$object	*(*getCertPath$5edc3811abd6d88d)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *);
};

// Vtable
struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vmethods	java_security_cert_PKIXCertPathValidatorResult;
	_jc_java_security_cert_PKIXCertPathBuilderResult$vmethods	java_security_cert_PKIXCertPathBuilderResult;
};

// Vtype
struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXCertPathBuilderResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs {
	struct _jc_java_security_cert_CertPath$object	*certPath;
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$refs {
    _jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs	java_security_cert_PKIXCertPathBuilderResult;
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs	java_security_cert_PKIXCertPathValidatorResult;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs	java_security_cert_PKIXCertPathValidatorResult;
    _jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs	java_security_cert_PKIXCertPathBuilderResult;
};

// Object instance structure
struct _jc_java_security_cert_PKIXCertPathBuilderResult$object {
	_jc_java_security_cert_PKIXCertPathBuilderResult$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXCertPathBuilderResult$vtype	*vtype;
	_jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXCertPathBuilderResult$vtype _jc_java_security_cert_PKIXCertPathBuilderResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXCertPathBuilderResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXCertPathBuilderResult$class_object;

#endif	/* _JC_java_security_cert_PKIXCertPathBuilderResult_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/PKIXCertPathBuilderResult.h <==
// public class java.security.cert.PKIXCertPathBuilderResult

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5f136bcfecde6164 java_security_cert_PKIXCertPathBuilderResult
// @dep_class e755c7543ee532d3 java_security_cert_PKIXCertPathValidatorResult

// header file dependencies
// @dep_header java_security_cert_PKIXCertPathValidatorResult

#include "java/security/cert/PKIXCertPathValidatorResult.h"

#ifndef _JC_java_security_cert_PKIXCertPathBuilderResult_H_
#define _JC_java_security_cert_PKIXCertPathBuilderResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_PolicyNode$object;
struct _jc_java_security_cert_TrustAnchor$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs	_jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs	_jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$refs	_jc_java_security_cert_PKIXCertPathBuilderResult$refs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs	_jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathBuilderResult$object	_jc_java_security_cert_PKIXCertPathBuilderResult$object;

typedef const struct _jc_java_security_cert_PKIXCertPathBuilderResult$vmethods	_jc_java_security_cert_PKIXCertPathBuilderResult$vmethods;
typedef const struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtable	_jc_java_security_cert_PKIXCertPathBuilderResult$vtable;
typedef const struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtype	_jc_java_security_cert_PKIXCertPathBuilderResult$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXCertPathBuilderResult$method$_init$c83cbb9627382e21(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_cert_CertPath$object *_jc_java_security_cert_PKIXCertPathBuilderResult$method$getCertPath$5edc3811abd6d88d(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PKIXCertPathBuilderResult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXCertPathBuilderResult$method_info$getCertPath$5edc3811abd6d88d;
extern _jc_method _jc_java_security_cert_PKIXCertPathBuilderResult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PKIXCertPathBuilderResult$vmethods {
	struct _jc_java_security_cert_CertPath$object	*(*getCertPath$5edc3811abd6d88d)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathBuilderResult$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vmethods	java_security_cert_PKIXCertPathValidatorResult;
	_jc_java_security_cert_PKIXCertPathBuilderResult$vmethods	java_security_cert_PKIXCertPathBuilderResult;
};

// Vtype
struct _jc_java_security_cert_PKIXCertPathBuilderResult$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXCertPathBuilderResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs {
	struct _jc_java_security_cert_CertPath$object	*certPath;
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$refs {
    _jc_java_security_cert_PKIXCertPathBuilderResult$sub_refs	java_security_cert_PKIXCertPathBuilderResult;
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs	java_security_cert_PKIXCertPathValidatorResult;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs	java_security_cert_PKIXCertPathValidatorResult;
    _jc_java_security_cert_PKIXCertPathBuilderResult$sub_nonrefs	java_security_cert_PKIXCertPathBuilderResult;
};

// Object instance structure
struct _jc_java_security_cert_PKIXCertPathBuilderResult$object {
	_jc_java_security_cert_PKIXCertPathBuilderResult$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXCertPathBuilderResult$vtype	*vtype;
	_jc_java_security_cert_PKIXCertPathBuilderResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXCertPathBuilderResult$vtype _jc_java_security_cert_PKIXCertPathBuilderResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXCertPathBuilderResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXCertPathBuilderResult$class_object;

#endif	/* _JC_java_security_cert_PKIXCertPathBuilderResult_H_ */
